@@ -18,11 +18,11 @@
 package org.apache.flink.connector.jdbc;
 
 import org.apache.flink.annotation.PublicEvolving;
+import org.apache.flink.connector.jdbc.core.datastream.sink.JdbcSinkBuilder;
 import org.apache.flink.connector.jdbc.datasource.connections.SimpleJdbcConnectionProvider;
 import org.apache.flink.connector.jdbc.internal.GenericJdbcSinkFunction;
 import org.apache.flink.connector.jdbc.internal.JdbcOutputFormat;
 import org.apache.flink.connector.jdbc.internal.executor.JdbcBatchStatementExecutor;
-import org.apache.flink.connector.jdbc.sink.JdbcSinkBuilder;
 import org.apache.flink.connector.jdbc.xa.JdbcXaSinkFunction;
 import org.apache.flink.connector.jdbc.xa.XaFacade;
 import org.apache.flink.streaming.api.functions.sink.SinkFunction;
@@ -30,8 +30,13 @@ import org.apache.flink.util.function.SerializableSupplier;
 
 import javax.sql.XADataSource;
 
-/** Facade to create JDBC {@link SinkFunction sinks}. */
+/**
+ * Facade to create JDBC {@link SinkFunction sinks}.
+ *
+ * @deprecated Use {@link org.apache.flink.connector.jdbc.core.datastream.Jdbc}
+ */
 @PublicEvolving
+@Deprecated
 public class JdbcSink {
 
     /**
@@ -109,7 +114,7 @@ public class JdbcSink {
     }
 
     public static <IN> JdbcSinkBuilder<IN> builder() {
-        return org.apache.flink.connector.jdbc.sink.JdbcSink.builder();
+        return org.apache.flink.connector.jdbc.core.datastream.sink.JdbcSink.builder();
     }
 
     private JdbcSink() {}
