@@ -19,39 +19,19 @@
 package org.apache.flink.connector.jdbc.source.reader.extractor;
 
 import org.apache.flink.annotation.PublicEvolving;
-import org.apache.flink.types.Row;
 
-import java.io.Serializable;
 import java.sql.ResultSet;
-import java.sql.SQLException;
 
 /**
  * The Extractor to extract the data from {@link ResultSet}.
  *
  * @param <T> The target data type.
+ * @deprecated Use {@link
+ *     org.apache.flink.connector.jdbc.core.datastream.source.reader.extractor.ResultExtractor}
  */
 @PublicEvolving
-public interface ResultExtractor<T> extends Serializable {
-
-    /**
-     * Extract the data from the current point line of the result.
-     *
-     * @param resultSet Result set queried from a sql.
-     * @return The data object filled by the current line of the resultSet.
-     * @throws SQLException SQL exception.
-     */
-    T extract(ResultSet resultSet) throws SQLException;
-
-    /**
-     * The identifier of the extractor.
-     *
-     * @return identifier in {@link String} type.
-     */
-    default String identifier() {
-        return this.getClass().getSimpleName();
-    }
-
-    static ResultExtractor<Row> ofRowResultExtractor() {
-        return new RowResultExtractor();
-    }
-}
+@Deprecated
+public interface ResultExtractor<T>
+        extends org.apache.flink.connector.jdbc.core.datastream.source.reader.extractor
+                        .ResultExtractor<
+                T> {}
