@@ -25,7 +25,7 @@ import org.apache.flink.api.common.time.Time;
 import org.apache.flink.configuration.Configuration;
 import org.apache.flink.connector.jdbc.JdbcExactlyOnceOptions;
 import org.apache.flink.connector.jdbc.JdbcExecutionOptions;
-import org.apache.flink.connector.jdbc.JdbcSink;
+import org.apache.flink.connector.jdbc.JdbcStatementBuilder;
 import org.apache.flink.connector.jdbc.testutils.DatabaseTest;
 import org.apache.flink.connector.jdbc.testutils.TableManaged;
 import org.apache.flink.connector.jdbc.testutils.tables.templates.BooksTable;
@@ -35,10 +35,12 @@ import org.apache.flink.runtime.testutils.MiniClusterResourceConfiguration;
 import org.apache.flink.streaming.api.CheckpointingMode;
 import org.apache.flink.streaming.api.checkpoint.CheckpointedFunction;
 import org.apache.flink.streaming.api.environment.StreamExecutionEnvironment;
+import org.apache.flink.streaming.api.functions.sink.SinkFunction;
 import org.apache.flink.streaming.api.functions.source.RichParallelSourceFunction;
 import org.apache.flink.streaming.api.functions.source.SourceFunction;
 import org.apache.flink.test.junit5.MiniClusterExtension;
 import org.apache.flink.util.ExceptionUtils;
+import org.apache.flink.util.function.SerializableSupplier;
 
 import org.junit.jupiter.api.AfterEach;
 import org.junit.jupiter.api.Test;
@@ -46,6 +48,8 @@ import org.junit.jupiter.api.extension.RegisterExtension;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.sql.XADataSource;
+
 import java.time.Duration;
 import java.util.Collections;
 import java.util.List;
@@ -68,6 +72,7 @@ import static org.apache.flink.util.Preconditions.checkState;
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** A simple end-to-end test for {@link JdbcXaSinkFunction}. */
+@Deprecated
 public abstract class JdbcExactlyOnceSinkE2eTest implements DatabaseTest {
 
     private static final Logger LOG = LoggerFactory.getLogger(JdbcExactlyOnceSinkE2eTest.class);
@@ -75,7 +80,7 @@ public abstract class JdbcExactlyOnceSinkE2eTest implements DatabaseTest {
     private static final BooksTable OUTPUT_TABLE = new BooksTable("XaTable");
     protected static final int PARALLELISM = 4;
     protected static final long CHECKPOINT_TIMEOUT_MS = 5_000L;
-    protected static final long TASK_CANCELLATION_TIMEOUT_MS = 10_000L;
+    protected static final String TASK_CANCELLATION_TIMEOUT_MS = "10000";
 
     @RegisterExtension static final MiniClusterExtension MINI_CLUSTER = createCluster();
 
@@ -85,7 +90,12 @@ public abstract class JdbcExactlyOnceSinkE2eTest implements DatabaseTest {
         // restart all tasks if at least one fails
         configuration.set(EXECUTION_FAILOVER_STRATEGY, "full");
         // cancel tasks eagerly to reduce the risk of running out of memory with many restarts
-        configuration.set(TASK_CANCELLATION_TIMEOUT, TASK_CANCELLATION_TIMEOUT_MS);
+        // TODO: Temporarily using the original configuration settings for CI compatibility
+        //  We should ensure that the current oldest flink version could process the configuration
+        // item correctly.
+        //  API calling lines will be adapted after the appropriate series versions
+        //  that the oldest flink version in the CI can process the config options.
+        configuration.setString(TASK_CANCELLATION_TIMEOUT.key(), TASK_CANCELLATION_TIMEOUT_MS);
         configuration.set(CHECKPOINTING_TIMEOUT, Duration.ofMillis(CHECKPOINT_TIMEOUT_MS));
 
         return new MiniClusterExtension(
@@ -135,7 +145,7 @@ public abstract class JdbcExactlyOnceSinkE2eTest implements DatabaseTest {
                 .setParallelism(PARALLELISM)
                 .map(new FailingMapper(numElementsPerCheckpoint + (numElementsPerCheckpoint / 2)))
                 .addSink(
-                        JdbcSink.exactlyOnceSink(
+                        exactlyOnceSink(
                                 OUTPUT_TABLE.getInsertIntoQuery(),
                                 OUTPUT_TABLE.getStatementBuilder(),
                                 JdbcExecutionOptions.builder().withMaxRetries(0).build(),
@@ -161,6 +171,23 @@ public abstract class JdbcExactlyOnceSinkE2eTest implements DatabaseTest {
                 System.currentTimeMillis() - started);
     }
 
+    private <T> SinkFunction<T> exactlyOnceSink(
+            String sql,
+            JdbcStatementBuilder<T> statementBuilder,
+            JdbcExecutionOptions executionOptions,
+            JdbcExactlyOnceOptions exactlyOnceOptions,
+            SerializableSupplier<XADataSource> dataSourceSupplier) {
+        return new JdbcXaSinkFunction<>(
+                sql,
+                statementBuilder,
+                XaFacade.fromXaDataSourceSupplier(
+                        dataSourceSupplier,
+                        exactlyOnceOptions.getTimeoutSec(),
+                        exactlyOnceOptions.isTransactionPerConnection()),
+                executionOptions,
+                exactlyOnceOptions);
+    }
+
     /**
      * {@link SourceFunction} emits {@link BooksTable.BookEntry test entries} and waits for the
      * checkpoint.
