@@ -19,6 +19,7 @@ package org.apache.flink.connector.jdbc.xa;
 
 import org.apache.flink.api.common.JobID;
 import org.apache.flink.api.common.functions.RuntimeContext;
+import org.apache.flink.connector.jdbc.datasource.transactions.xa.xid.XidImpl;
 
 import org.junit.jupiter.api.Test;
 
@@ -32,6 +33,7 @@ import static org.apache.flink.connector.jdbc.xa.JdbcXaSinkTestBase.TEST_RUNTIME
 import static org.assertj.core.api.Assertions.assertThat;
 
 /** Simple uniqueness tests for the {@link SemanticXidGenerator}. */
+@Deprecated
 class SemanticXidGeneratorTest {
     private static final int COUNT = 100_000;
 
